searchData={"items":[{"type":"module","title":"Mail","doc":"Mail primitive for composing messages.\n\nBuild a mail message with the `Mail` struct\n\n    mail =\n      Mail.build_multipart()\n      |> put_subject(\"How is it going?\")\n      |> Mail.put_text(\"Just checking in\")\n      |> Mail.put_to(\"joe@example.com\")\n      |> Mail.put_from(\"brian@example.com\")","ref":"Mail.html"},{"type":"function","title":"Mail.all_recipients/1","doc":"Returns a unique list of all recipients\n\nWill collect all recipients from `to`, `cc`, and `bcc`\nand returns a unique list of recipients.","ref":"Mail.html#all_recipients/1"},{"type":"function","title":"Mail.build/0","doc":"Build a single-part mail","ref":"Mail.html#build/0"},{"type":"function","title":"Mail.build_multipart/0","doc":"Build a multi-part mail","ref":"Mail.html#build_multipart/0"},{"type":"function","title":"Mail.get_attachments/1","doc":"Walks the message parts and collects all attachments\n\nEach member in the list is `{filename, content}`","ref":"Mail.html#get_attachments/1"},{"type":"function","title":"Mail.get_bcc/1","doc":"Retrieves the recipients from the `bcc` header","ref":"Mail.html#get_bcc/1"},{"type":"function","title":"Mail.get_cc/1","doc":"Retrieves the recipients from the `cc` header","ref":"Mail.html#get_cc/1"},{"type":"function","title":"Mail.get_from/1","doc":"Retrieves the `from` header","ref":"Mail.html#get_from/1"},{"type":"function","title":"Mail.get_html/1","doc":"Find the last html part of a given mail\n\nRFC 2046, §5.1.4 “In general, the best choice is the LAST part of a type supported by the recipient system's local environment.”\n\nIf single part with `content-type` \"text/html\", returns itself\nIf single part without `content-type` \"text/html\", returns `nil`\nIf multipart with part having `content-type` \"text/html\" will return that part\nIf multipart without part having `content-type` \"text/html\" will return `nil`","ref":"Mail.html#get_html/1"},{"type":"function","title":"Mail.get_reply_to/1","doc":"Retrieves the `reply-to` header","ref":"Mail.html#get_reply_to/1"},{"type":"function","title":"Mail.get_subject/1","doc":"Retrieve the `subject` header","ref":"Mail.html#get_subject/1"},{"type":"function","title":"Mail.get_text/1","doc":"Find the last text part of a given mail\n\nRFC 2046, §5.1.4 “In general, the best choice is the LAST part of a type supported by the recipient system's local environment.”\n\nIf single part with `content-type` \"text/plain\", returns itself\nIf single part without `content-type` \"text/plain\", returns `nil`\nIf multipart with part having `content-type` \"text/plain\" will return that part\nIf multipart without part having `content-type` \"text/plain\" will return `nil`","ref":"Mail.html#get_text/1"},{"type":"function","title":"Mail.get_to/1","doc":"Retrieves the list of recipients from the `to` header","ref":"Mail.html#get_to/1"},{"type":"function","title":"Mail.has_attachments?/1","doc":"Determines the message has any attachment parts\n\nReturns a `Boolean`","ref":"Mail.html#has_attachments?/1"},{"type":"function","title":"Mail.has_text_parts?/1","doc":"Determines the message has any text parts\n\nReturns a `Boolean`","ref":"Mail.html#has_text_parts?/1"},{"type":"function","title":"Mail.parse/2","doc":"Primary hook for parsing\n\nYou can pass in your own custom parse module. That module\nmust have a `parse/1` function that accepts a string or list of lines\n\nBy default the `parser` will be `Mail.Parsers.RFC2822`","ref":"Mail.html#parse/2"},{"type":"function","title":"Mail.put_attachment/3","doc":"Add an attachment part to the message\n\n    Mail.put_attachment(%Mail.Message{}, \"README.md\")\n    Mail.put_attachment(%Mail.Message{}, {\"README.md\", data})\n\nEach call will add a new attachment part.","ref":"Mail.html#put_attachment/3"},{"type":"function","title":"Mail.put_bcc/2","doc":"Add new recipients to the `bcc` header\n\nRecipients can be added as a single string or a list of strings.\nThe list of recipients will be concated to the previous value.\n\n    Mail.put_bcc(%Mail.Message{}, \"one@example.com\")\n    %Mail.Message{headers: %{bcc: [\"one@example.com\"]}}\n\n    Mail.put_bcc(%Mail.Message{}, [\"one@example.com\", \"two@example.com\"])\n    %Mail.Message{headers: %{bcc: [\"one@example.com\", \"two@example.com\"]}}\n\n    Mail.put_bcc(%Mail.Message{}, \"one@example.com\")\n    |> Mail.put_bcc([\"two@example.com\", \"three@example.com\"])\n    %Mail.Message{headers: %{bcc: [\"one@example.com\", \"two@example.com\", \"three@example.com\"]}}\n\nThe value of a recipient must conform to either a string value or a tuple with two elements,\notherwise an `ArgumentError` is raised.\n\nValid forms:\n* `\"user@example.com\"`\n* `\"Test User  \"`\n* `{\"Test User\", \"user@example.com\"}`","ref":"Mail.html#put_bcc/2"},{"type":"function","title":"Mail.put_cc/2","doc":"Add new recipients to the `cc` header\n\nRecipients can be added as a single string or a list of strings.\nThe list of recipients will be concated to the previous value.\n\n    Mail.put_cc(%Mail.Message{}, \"one@example.com\")\n    %Mail.Message{headers: %{cc: [\"one@example.com\"]}}\n\n    Mail.put_cc(%Mail.Message{}, [\"one@example.com\", \"two@example.com\"])\n    %Mail.Message{headers: %{cc: [\"one@example.com\", \"two@example.com\"]}}\n\n    Mail.put_cc(%Mail.Message{}, \"one@example.com\")\n    |> Mail.put_cc([\"two@example.com\", \"three@example.com\"])\n    %Mail.Message{headers: %{cc: [\"one@example.com\", \"two@example.com\", \"three@example.com\"]}}\n\nThe value of a recipient must conform to either a string value or a tuple with two elements,\notherwise an `ArgumentError` is raised.\n\nValid forms:\n* `\"user@example.com\"`\n* `\"Test User  \"`\n* `{\"Test User\", \"user@example.com\"}`","ref":"Mail.html#put_cc/2"},{"type":"function","title":"Mail.put_from/2","doc":"Add a new `from` header\n\n    Mail.put_from(%Mail.Message{}, \"user@example.com\")\n    %Mail.Message{headers: %{from: \"user@example.com\"}}","ref":"Mail.html#put_from/2"},{"type":"function","title":"Mail.put_html/3","doc":"Add an HTML part to the message\n\n    Mail.put_html(%Mail.Message{}, \" Some HTML \")\n\nIf a text part already exists this function will replace that existing\npart with the new part.","ref":"Mail.html#put_html/3"},{"type":"function","title":"Options - Mail.put_html/3","doc":"* `:charset` - The character encoding standard for content type","ref":"Mail.html#put_html/3-options"},{"type":"function","title":"Mail.put_reply_to/2","doc":"Add a new `reply-to` header\n\n    Mail.put_reply_to(%Mail.Message{}, \"user@example.com\")\n    %Mail.Message{headers: %{reply_to: \"user@example.com\"}}","ref":"Mail.html#put_reply_to/2"},{"type":"function","title":"Mail.put_subject/2","doc":"Add a new `subject` header\n\n    Mail.put_subject(%Mail.Message{}, \"Welcome to DockYard!\")\n    %Mail.Message{headers: %{subject: \"Welcome to DockYard!\"}}","ref":"Mail.html#put_subject/2"},{"type":"function","title":"Mail.put_text/3","doc":"Add a plaintext part to the message\n\nShortcut function for adding plain text part\n\n    Mail.put_text(%Mail.Message{}, \"Some plain text\")\n\nIf a text part already exists this function will replace that existing\npart with the new part.","ref":"Mail.html#put_text/3"},{"type":"function","title":"Options - Mail.put_text/3","doc":"* `:charset` - The character encoding standard for content type","ref":"Mail.html#put_text/3-options"},{"type":"function","title":"Mail.put_to/2","doc":"Add new recipients to the `to` header\n\nRecipients can be added as a single string or a list of strings.\nThe list of recipients will be concated to the previous value.\n\n    Mail.put_to(%Mail.Message{}, \"one@example.com\")\n    %Mail.Message{headers: %{to: [\"one@example.com\"]}}\n\n    Mail.put_to(%Mail.Message{}, [\"one@example.com\", \"two@example.com\"])\n    %Mail.Message{headers: %{to: [\"one@example.com\", \"two@example.com\"]}}\n\n    Mail.put_to(%Mail.Message{}, \"one@example.com\")\n    |> Mail.put_to([\"two@example.com\", \"three@example.com\"])\n    %Mail.Message{headers: %{to: [\"one@example.com\", \"two@example.com\", \"three@example.com\"]}}\n\nThe value of a recipient must conform to either a string value or a tuple with two elements,\notherwise an `ArgumentError` is raised.\n\nValid forms:\n* `\"user@example.com\"`\n* `\"Test User  \"`\n* `{\"Test User\", \"user@example.com\"}`","ref":"Mail.html#put_to/2"},{"type":"function","title":"Mail.render/2","doc":"Primary hook for rendering\n\nYou can pass in your own custom render module. That module\nmust have `render/1` function that accepts a `Mail.Message` struct.\n\nBy default the `renderer` will be `Mail.Renderers.RFC2822`","ref":"Mail.html#render/2"},{"type":"module","title":"Mail.Encoder","doc":"Primary encoding/decoding bottleneck for the library.\n\nWill delegate to the proper encoding/decoding functions based upon name","ref":"Mail.Encoder.html"},{"type":"function","title":"Mail.Encoder.decode/2","doc":"","ref":"Mail.Encoder.html#decode/2"},{"type":"function","title":"Mail.Encoder.encode/2","doc":"","ref":"Mail.Encoder.html#encode/2"},{"type":"function","title":"Mail.Encoder.encoder_for/1","doc":"","ref":"Mail.Encoder.html#encoder_for/1"},{"type":"module","title":"Mail.Encoders.Base64","doc":"Encodes/decodes base64 strings according to RFC 2045 which requires line\nlengths of less than 76 characters and illegal characters to be removed\nduring parsing.\n\nSee the following links for reference:\n-  \n-  \n-","ref":"Mail.Encoders.Base64.html"},{"type":"function","title":"Mail.Encoders.Base64.decode/1","doc":"","ref":"Mail.Encoders.Base64.html#decode/1"},{"type":"function","title":"Mail.Encoders.Base64.encode/1","doc":"","ref":"Mail.Encoders.Base64.html#encode/1"},{"type":"module","title":"Mail.Encoders.Binary","doc":"Encodes/decodes binary strings according to RFC 2045.\n\nSee the following link for reference:\n-","ref":"Mail.Encoders.Binary.html"},{"type":"function","title":"Mail.Encoders.Binary.decode/1","doc":"Decodes a binary encoded string.","ref":"Mail.Encoders.Binary.html#decode/1"},{"type":"function","title":"Mail.Encoders.Binary.encode/1","doc":"Encodes a string into a binary encoded string.","ref":"Mail.Encoders.Binary.html#encode/1"},{"type":"module","title":"Mail.Encoders.EightBit","doc":"Encodes/decodes 8-bit strings according to RFC 2045.\n\nSee the following link for reference:\n-","ref":"Mail.Encoders.EightBit.html"},{"type":"function","title":"Mail.Encoders.EightBit.decode/1","doc":"Decodes an 8-bit encoded string.","ref":"Mail.Encoders.EightBit.html#decode/1"},{"type":"function","title":"Mail.Encoders.EightBit.encode/1","doc":"Encodes a string into an 8-bit encoded string.\n\nRaises if any character is   \"\u0000\".","ref":"Mail.Encoders.EightBit.html#encode/1"},{"type":"module","title":"Mail.Encoders.QuotedPrintable","doc":"Encodes/decodes quoted-printable strings according to RFC 2045.\n\nSee the following links for reference:\n-","ref":"Mail.Encoders.QuotedPrintable.html"},{"type":"function","title":"Mail.Encoders.QuotedPrintable.decode/2","doc":"Decodes a quoted-printable encoded string.","ref":"Mail.Encoders.QuotedPrintable.html#decode/2"},{"type":"function","title":"Examples - Mail.Encoders.QuotedPrintable.decode/2","doc":"Mail.QuotedPrintable.decode(\"fa=C3=A7ade\")\n    \"façade\"","ref":"Mail.Encoders.QuotedPrintable.html#decode/2-examples"},{"type":"function","title":"Mail.Encoders.QuotedPrintable.encode/4","doc":"Encodes a string into a quoted-printable encoded string.","ref":"Mail.Encoders.QuotedPrintable.html#encode/4"},{"type":"function","title":"Examples - Mail.Encoders.QuotedPrintable.encode/4","doc":"Mail.Encoders.QuotedPrintable.encode(\"façade\")\n    \"fa=C3=A7ade\"","ref":"Mail.Encoders.QuotedPrintable.html#encode/4-examples"},{"type":"module","title":"Mail.Encoders.SevenBit","doc":"Encodes/decodes 7-bit strings according to RFC 2045.\n\nSee the following link for reference:\n-","ref":"Mail.Encoders.SevenBit.html"},{"type":"function","title":"Mail.Encoders.SevenBit.decode/1","doc":"Decodes a 7-bit encoded string.","ref":"Mail.Encoders.SevenBit.html#decode/1"},{"type":"function","title":"Mail.Encoders.SevenBit.encode/1","doc":"Encodes a string into a 7-bit encoded string.\n\nRaises if any character isn't in the 7-bit ASCII range 1..127.","ref":"Mail.Encoders.SevenBit.html#encode/1"},{"type":"module","title":"Mail.MIME","doc":"","ref":"Mail.MIME.html"},{"type":"function","title":"Mail.MIME.type/1","doc":"Returns the mimetype for a given file extension.\n\n    Mail.Mimetype.type(\"md\")\n    \"text/markdown\"","ref":"Mail.MIME.html#type/1"},{"type":"module","title":"Mail.Message","doc":"","ref":"Mail.Message.html"},{"type":"function","title":"Mail.Message.build_attachment/2","doc":"Add attachment meta data to a `Mail.Message`\n\nWill allow you to create a new part that is meant to be used as an\nattachment.\n\nYou can pass either a filepath or a tuple as the second argument. If a\ntuple is being passed the tuple must only have two elements:\n`{filename, filedata}`.\n\nThe mimetype of the file is determined by the file extension.\n\n    Mail.Message.build_attachment(\"README.md\")\n    %Mail.Message{data: \"base64 encoded\", headers: %{content_type: [\"text/x-markdown\"], content_disposition: [\"attachment\", filename: \"README.md\"], content_transfer_encoding: :base64}}\n\n    Mail.Message.build_attachment({\"README.md\", \"file contents\"})\n    %Mail.Message{data: \"base64 encoded\", headers: %{content_type: [\"text/x-markdown\"], content_disposition: [\"attachment\", filename: \"README.md\"], content_transfer_encoding: :base64}}","ref":"Mail.Message.html#build_attachment/2"},{"type":"function","title":"Options - Mail.Message.build_attachment/2","doc":"See `put_attachment/3` for options","ref":"Mail.Message.html#build_attachment/2-options"},{"type":"function","title":"Custom mimetype library - Mail.Message.build_attachment/2","doc":"By default `Mail` will use its own internal mimetype adapter. However,\nyou may want to rely on `Plug` and the custom mimetypes that you have\ncreated for it. You can override the mimetype function in the\n`config.exs` of your application:\n\n    config :mail, mimetype_fn: &CustomMimeAdapter.type/1\n\nThis function should take a string that is the file extension. It\nshould return a single mimetype.\n\n    CustomMimeAdapter.type(\"md\")\n    \"text/markdown\"","ref":"Mail.Message.html#build_attachment/2-custom-mimetype-library"},{"type":"function","title":"Mail.Message.build_html/2","doc":"Build a new HTML message\n\n    Mail.Message.build_html(\" Some HTML \")\n    %Mail.Message{body: \" Some HTML \", headers: %{content_type: \"text/html\"}}\n\n    Mail.Message.build_html(\" Some HTML \", charset: \"UTF-8\")\n    %Mail.Message{body: \" Some HTML \", headers: %{content_type: [\"text/html\", {\"charset\", \"UTF-8\"}]}}","ref":"Mail.Message.html#build_html/2"},{"type":"function","title":"Options - Mail.Message.build_html/2","doc":"* `:charset` - The character encoding standard for content type","ref":"Mail.Message.html#build_html/2-options"},{"type":"function","title":"Mail.Message.build_text/2","doc":"Build a new text message\n\n    Mail.Message.build_text(\"Some text\")\n    %Mail.Message{body: \"Some text\", headers: %{content_type: \"text/plain\"}}\n\n    Mail.Message.build_text(\"Some text\", charset: \"UTF-8\")\n    %Mail.Message{body: \"Some text\", headers: %{content_type: [\"text/plain\", {\"charset\", \"UTF-8\"}]}}","ref":"Mail.Message.html#build_text/2"},{"type":"function","title":"Options - Mail.Message.build_text/2","doc":"* `:charset` - The character encoding standard for content type","ref":"Mail.Message.html#build_text/2-options"},{"type":"function","title":"Mail.Message.delete_header/2","doc":"Deletes a specific header key\n\n    Mail.Message.delete_header(%Mail.Message{headers: %{foo: \"bar\"}}, :foo)\n    %Mail.Message{headers: %{}}","ref":"Mail.Message.html#delete_header/2"},{"type":"function","title":"Mail.Message.delete_headers/2","doc":"Deletes a list of headers\n\n    Mail.Message.delete_headers(%Mail.Message{headers: %{foo: \"bar\", baz: \"qux\"}}, [:foo, :baz])\n    %Mail.Message{headers: %{}}","ref":"Mail.Message.html#delete_headers/2"},{"type":"function","title":"Mail.Message.delete_part/2","doc":"Delete a matching part\n\nWill delete a matching part in the `parts` list. If the part\nis not found no error is raised.","ref":"Mail.Message.html#delete_part/2"},{"type":"function","title":"Mail.Message.get_boundary/1","doc":"Gets the boundary value from the `content_type` header\n\nWill retrieve the boundary value. If one is not set a random one is generated.\n\n    Mail.Message.get_boundary(%Mail.Message{headers: %{content_type: [\"multipart/mixed\", {\"boundary\", \"foobar\"}]}})\n    \"foobar\"\n\n    Mail.Message.get_boundary(%Mail.Message{headers: %{content_type: [\"multipart/mixed\"]}})\n    \"ASDFSHNEW3473423\"","ref":"Mail.Message.html#get_boundary/1"},{"type":"function","title":"Mail.Message.get_content_type/1","doc":"Gets the `content_type` from the header\n\nWill ensure the `content_type` is always wrapped in a `List`\n\n    Mail.Message.get_content_type(%Mail.Message{})\n    [\"\"]\n\n    Mail.Message.get_content_type(%Mail.Message{content_type: \"text/plain\"})\n    [\"text/plain\"]\n\n    Mail.Message.get_content_type(%Mail.Message{headers: %{content_type: [\"multipart/mixed\", {\"boundary\", \"foobar\"}]}})\n    [\"multipart/mixed\", {\"boundary\", \"foobar\"}]","ref":"Mail.Message.html#get_content_type/1"},{"type":"function","title":"Mail.Message.get_header/2","doc":"","ref":"Mail.Message.html#get_header/2"},{"type":"function","title":"Mail.Message.has_attachment?/1","doc":"Determines the message has any attachment parts\n\nReturns a `Boolean`","ref":"Mail.Message.html#has_attachment?/1"},{"type":"function","title":"Mail.Message.has_header?/2","doc":"","ref":"Mail.Message.html#has_header?/2"},{"type":"function","title":"Mail.Message.has_text_part?/1","doc":"Determines the message has any text (`text/plain` or `text/html`) parts\n\nReturns a `Boolean`","ref":"Mail.Message.html#has_text_part?/1"},{"type":"function","title":"Mail.Message.is_attachment?/1","doc":"Is the part an attachment or not\n\nReturns `Boolean`","ref":"Mail.Message.html#is_attachment?/1"},{"type":"function","title":"Mail.Message.is_text_part?/1","doc":"Is the message text based or not\n\nCan be a message with a `content_type` of `text/plain` or `text/html`\n\nReturns `Boolean`","ref":"Mail.Message.html#is_text_part?/1"},{"type":"function","title":"Mail.Message.match_body_text/1","doc":"","ref":"Mail.Message.html#match_body_text/1"},{"type":"function","title":"Mail.Message.match_content_type?/2","doc":"Will match on a full or partial content type\n\n    Mail.Message.match_content_type?(message, ~r/text/)\n    true\n\n    Mail.Message.match_content_type?(message, \"text/html\")\n    false","ref":"Mail.Message.html#match_content_type?/2"},{"type":"function","title":"Mail.Message.put_attachment/3","doc":"Adds a new attachment part to the provided message\n\nThe first argument must be a `Mail.Message`. The remaining argument is described in `build_attachment/1`","ref":"Mail.Message.html#put_attachment/3"},{"type":"function","title":"Options - Mail.Message.put_attachment/3","doc":"* `:headers` - Headers to be merged","ref":"Mail.Message.html#put_attachment/3-options"},{"type":"function","title":"Examples - Mail.Message.put_attachment/3","doc":"Mail.Message.put_attachment(%Mail.Message{}, \"README.md\")\n    %Mail.Message{data: \"base64 encoded\", headers: %{content_type: [\"text/x-markdown\"], content_disposition: [\"attachment\", filename: \"README.md\"], content_transfer_encoding: :base64}}\n\n    Mail.Message.put_attachment(%Mail.Message{}, {\"README.md\", \"file contents\"})\n    %Mail.Message{data: \"base64 encoded\", headers: %{content_type: [\"text/x-markdown\"], content_disposition: [\"attachment\", filename: \"README.md\"], content_transfer_encoding: :base64}}\n\n#","ref":"Mail.Message.html#put_attachment/3-examples"},{"type":"function","title":"Adding custom headers - Mail.Message.put_attachment/3","doc":"Mail.Message.put_attachment(%Mail.Message{}, \"README.md\", headers: [content_id: \"attachment-id\"])\n    %Mail.Message{data: \"base64 encoded\", headers: %{content_type: [\"text/x-markdown\"], content_disposition: [\"attachment\", filename: \"README.md\"], content_transfer_encoding: :base64, content_id: \"attachment-id\"}}\n\n    Mail.Message.put_attachment(%Mail.Message{}, {\"README.md\", data}, headers: [content_id: \"attachment-id\"])\n    %Mail.Message{data: \"base64 encoded\", headers: %{content_type: [\"text/x-markdown\"], content_disposition: [\"attachment\", filename: \"README.md\"], content_transfer_encoding: :base64, content_id: \"attachment-id\"}}","ref":"Mail.Message.html#put_attachment/3-adding-custom-headers"},{"type":"function","title":"Mail.Message.put_body/2","doc":"Sets the `body` field on the part\n\n    Mail.Message.put_body(%Mail.Message{}, \"Some data\")\n    %Mail.Message{body: \"Some Data\", headers: %{}}","ref":"Mail.Message.html#put_body/2"},{"type":"function","title":"Mail.Message.put_boundary/2","doc":"Adds a boundary value to the `content_type` header\n\nWill overwrite existing `boundary` key in the list. Will preserve other\nvalues in the list\n\n    Mail.Message.put_boundary(%Mail.Message{}, \"foobar\")\n    %Mail.Message{headers: %{content_type: [\"\", {\"boundary\", \"foobar\"}]}}\n\n    Mail.Message.put_boundary(%Mail.Message{headers: %{content_type: [\"multipart/mixed\", {\"boundary\", \"bazqux\"}]}})\n    %Mail.Message{headers: %{content_type: [\"multipart/mixed\", {\"boundary\", \"foobar\"}]}}","ref":"Mail.Message.html#put_boundary/2"},{"type":"function","title":"Mail.Message.put_content_type/2","doc":"Add a new `content-type` header\n\nThe value will always be wrapped in a `List`\n\n    Mail.Message.put_content_type(%Mail.Message{}, \"text/plain\")\n    %Mail.Message{headers: %{content_type: [\"text/plain\"]}}","ref":"Mail.Message.html#put_content_type/2"},{"type":"function","title":"Mail.Message.put_header/3","doc":"Add a new header key/value pair\n\n    Mail.Message.put_header(%Mail.Message{}, :content_type, \"text/plain\")\n\nThe individual headers will be in the `headers` field on the\n`%Mail.Message{}` struct","ref":"Mail.Message.html#put_header/3"},{"type":"function","title":"Mail.Message.put_part/2","doc":"Add new part\n\n    Mail.Message.put_part(%Mail.Message{}, %Mail.Message{})","ref":"Mail.Message.html#put_part/2"},{"type":"type","title":"Mail.Message.t/0","doc":"","ref":"Mail.Message.html#t:t/0"},{"type":"module","title":"Mail.Parsers.RFC2822","doc":"RFC2822 Parser\n\nWill attempt to parse a valid RFC2822 message back into\na `%Mail.Message{}` data model.\n\n    Mail.Parsers.RFC2822.parse(message)\n    %Mail.Message{body: \"Some message\", headers: %{to: [\"user@example.com\"], from: \"other@example.com\", subject: \"Read this!\"}}","ref":"Mail.Parsers.RFC2822.html"},{"type":"function","title":"Mail.Parsers.RFC2822.parse/1","doc":"","ref":"Mail.Parsers.RFC2822.html#parse/1"},{"type":"function","title":"Mail.Parsers.RFC2822.parse_recipient_value/1","doc":"Retrieves the \"name\" and \"address\" parts from an email message recipient\n(To, CC, etc.). The following is an example of recipient value:\n\n    Full Name  , another@company.tld\n\nIn this example, `Full Name` is the \"name\" part and `fullname@company.tld` is\nthe \"address\" part. `another@company.tld` does not have a \"name\" part, only\nan \"address\" part.\n\nThe return value is a mixed list of tuples and strings, which should be\ninterpreted in the following way:\n- When the element is just a string, it represents the \"address\" part only\n- When the element is a tuple, the format is `{name, address}`. Both \"name\"\n  and \"address\" are strings","ref":"Mail.Parsers.RFC2822.html#parse_recipient_value/1"},{"type":"function","title":"Mail.Parsers.RFC2822.to_datetime/1","doc":"Parses a RFC2822 timestamp to a DateTime with timezone\n\n[RFC2822 3.3 - Date and Time Specification](https://tools.ietf.org/html/rfc2822#section-3.3)\n\nAlso supports obsolete format described in [RFC2822 4.3](https://datatracker.ietf.org/doc/html/rfc2822#section-4.3)\nand invalid timestamps encountered in the wild. The return value will be either a UTC DateTime, or an error tuple\nreturning the invalid date string.","ref":"Mail.Parsers.RFC2822.html#to_datetime/1"},{"type":"module","title":"Mail.Proplist","doc":"A hybrid of Erlang's proplists and lists keystores.\n\nIt acts as a Set for key-value pairs, but still maintains it's order like a\nList.","ref":"Mail.Proplist.html"},{"type":"function","title":"Mail.Proplist.delete/2","doc":"Removes a key-value pair by the given key and returns the remaining list\n\nArgs:\n* `list` - the list to remove the pair from\n* `key` - the key to remove","ref":"Mail.Proplist.html#delete/2"},{"type":"function","title":"Mail.Proplist.drop/2","doc":"Drops the specified keys from the list, returning the remaining.\n\nArgs:\n* `list` - the list\n* `keys` - the keys to remove","ref":"Mail.Proplist.html#drop/2"},{"type":"function","title":"Mail.Proplist.filter/2","doc":"Filters the proplist, i.e. returns only those elements\nfor which `fun` returns a truthy value.\n\nArgs:\n* `list` - the list to filter\n* `func` - the function to execute","ref":"Mail.Proplist.html#filter/2"},{"type":"function","title":"Mail.Proplist.get/2","doc":"Retrieves a value from the list\n\nArgs:\n* `list` - the list to look in\n* `key` - the key of the pair to retrieve it's value","ref":"Mail.Proplist.html#get/2"},{"type":"function","title":"Mail.Proplist.has_key?/2","doc":"Detects if the list contains the specified key.\n\nArgs:\n* `list` - the list to look in\n* `key` - the key to look for","ref":"Mail.Proplist.html#has_key?/2"},{"type":"function","title":"Mail.Proplist.keys/1","doc":"Retrieves all keys from the key value pairs present in the list,\nunlike :proplists.get_keys which will return non-kv pairs as keys\n\nArgs:\n* `list` - a list to retrieve all the keys from","ref":"Mail.Proplist.html#keys/1"},{"type":"function","title":"Mail.Proplist.merge/2","doc":"Concatenates the given lists.\n\nArgs:\n* `a` - base list to merge unto\n* `b` - list to merge with","ref":"Mail.Proplist.html#merge/2"},{"type":"function","title":"Mail.Proplist.normalize/1","doc":"Merges duplicate pairs with the latest value.\n\nArgs:\n* `list` - the list to normalize","ref":"Mail.Proplist.html#normalize/1"},{"type":"function","title":"Mail.Proplist.prepend/3","doc":"Prepends the key-value pair to the list if it doesn't already exist, otherwise\nit will replace the existing pair\n\nArgs:\n* `list` - the list to store in\n* `key` - the key of the pair\n* `value` - the value of the pair","ref":"Mail.Proplist.html#prepend/3"},{"type":"function","title":"Mail.Proplist.put/3","doc":"Stores a key-value pair in the list, will replace an existing pair with the\nsame key.\n\nArgs:\n* `list` - the list to store in\n* `key` - the key of the pair\n* `value` - the value of the pair","ref":"Mail.Proplist.html#put/3"},{"type":"function","title":"Mail.Proplist.take/2","doc":"Takes the specified keys from the list, returning the remaining.\n\nArgs:\n* `list` - the list\n* `keys` - the keys to keep","ref":"Mail.Proplist.html#take/2"},{"type":"type","title":"Mail.Proplist.t/0","doc":"","ref":"Mail.Proplist.html#t:t/0"},{"type":"module","title":"Mail.Renderers.RFC2822","doc":"RFC2822 Parser\n\nWill attempt to render a valid RFC2822 message\nfrom a `%Mail.Message{}` data model.\n\n    Mail.Renderers.RFC2822.render(message)\n\nThe email validation regex defaults to `~r/w+@w+.w+/`\nand can be overridden with the following config:\n\n    config :mail, email_regex: custom_regex","ref":"Mail.Renderers.RFC2822.html"},{"type":"function","title":"Mail.Renderers.RFC2822.render/1","doc":"Renders a message according to the RFC2822 spec","ref":"Mail.Renderers.RFC2822.html#render/1"},{"type":"function","title":"Mail.Renderers.RFC2822.render_header/2","doc":"Will render a given header according to the RFC2822 spec","ref":"Mail.Renderers.RFC2822.html#render_header/2"},{"type":"function","title":"Mail.Renderers.RFC2822.render_headers/2","doc":"Will render all headers according to the RFC2822 spec\n\nCan take an optional list of headers to blacklist","ref":"Mail.Renderers.RFC2822.html#render_headers/2"},{"type":"function","title":"Mail.Renderers.RFC2822.render_part/2","doc":"Render an individual part\n\nAn optional function can be passed used during the rendering of each\nindividual part","ref":"Mail.Renderers.RFC2822.html#render_part/2"},{"type":"function","title":"Mail.Renderers.RFC2822.render_parts/2","doc":"","ref":"Mail.Renderers.RFC2822.html#render_parts/2"},{"type":"function","title":"Mail.Renderers.RFC2822.timestamp_from_datetime/1","doc":"Builds a RFC2822 timestamp from an Erlang timestamp\n\n[RFC2822 3.3 - Date and Time Specification](https://tools.ietf.org/html/rfc2822#section-3.3)\n\nThis function always assumes the Erlang timestamp is in Universal time, not Local time","ref":"Mail.Renderers.RFC2822.html#timestamp_from_datetime/1"},{"type":"module","title":"Mail.TestAssertions","doc":"Primitives for building your own assertions for Mail.Message\nrenderers.\n\nA custom assertion should implement its own parser. The result of the\nparsing the actual message and the expected message is then passed\ninto `compare/2`","ref":"Mail.TestAssertions.html"},{"type":"function","title":"Mail.TestAssertions.compare/2","doc":"Primary hook used by rendered mail assertions. Expected parsed\nmessages.","ref":"Mail.TestAssertions.html#compare/2"},{"type":"extras","title":"Changelog","doc":"# Changelog","ref":"changelog.html"},{"type":"extras","title":"0.4.0 2024-10-02 - Changelog","doc":"* Change date parser to return {:error, date_text} when date is unparsable https://github.com/DockYard/elixir-mail/pull/169\n* Ignore space between two encoded words (as per RFC 2047) https://github.com/DockYard/elixir-mail/pull/168\n* Change order of part lookup to match RFC 2046, §5.1.4 https://github.com/DockYard/elixir-mail/pull/167\n* Fix 8-bit decoding to preserve line breaks but restore wrapping https://github.com/DockYard/elixir-mail/pull/166\n* Fix 7-bit decoding to preserve line breaks but restore wrapping https://github.com/DockYard/elixir-mail/pull/164\n* Fix decoding of encoded words with spaces https://github.com/DockYard/elixir-mail/pull/160\n* Default to UTF-8 charset https://github.com/DockYard/elixir-mail/pull/162\n* Add support for case insensitive headers https://github.com/DockYard/elixir-mail/pull/161","ref":"changelog.html#0-4-0-2024-10-02"},{"type":"extras","title":"0.3.1 2023-08-04 - Changelog","doc":"* Fix get_attachments/1 for attachments without filename prop https://github.com/DockYard/elixir-mail/pull/154","ref":"changelog.html#0-3-1-2023-08-04"},{"type":"extras","title":"0.3.0 2023-08-01 - Changelog","doc":"* Add DateTime and time zone support to date parsing/rendering\n* Add Mail.parse/2 with default RFC2822 parser\n* Use a binary accumulator in QuotedPrintable encoder to reduce memory https://github.com/DockYard/elixir-mail/pull/145\n* Handle strings that appear to be quoted printable but are not https://github.com/DockYard/elixir-mail/pull/141\n* Provide default charset when no charset specified https://github.com/DockYard/elixir-mail/pull/144\n* Fix handling obsolete timezone (UT) in obsolete date/time format https://github.com/DockYard/elixir-mail/pull/143\n* Split encoded words on headers https://github.com/DockYard/elixir-mail/pull/134","ref":"changelog.html#0-3-0-2023-08-01"},{"type":"extras","title":"0.2.3 2021-06-28 - Changelog","doc":"* Add support for incorrect case in date parsing https://github.com/DockYard/elixir-mail/pull/132\n* Support quoted-printable encoding in message headers https://github.com/DockYard/elixir-mail/pull/131","ref":"changelog.html#0-2-3-2021-06-28"},{"type":"extras","title":"0.2.2 2020-07-28 - Changelog","doc":"* Documentation updates\n* Handle parsing a recipient name which is an email address https://github.com/DockYard/elixir-mail/pull/123\n* Add charset option to text, html part https://github.com/DockYard/elixir-mail/pull/122\n* Add support for custom headers on attachments https://github.com/DockYard/elixir-mail/pull/120\n* Add support for part without body https://github.com/DockYard/elixir-mail/pull/115\n* Add support for multiple values in the content-type header in Mail.get_text https://github.com/DockYard/elixir-mail/pull/108\n* Fix for #105 where put_text/2 would replace plain text attachment https://github.com/DockYard/elixir-mail/pull/106\n* RFC2822 parse recipient value is now part of public API https://github.com/DockYard/elixir-mail/pull/104\n* Various fixes for bugs found in parsing real email https://github.com/DockYard/elixir-mail/pull/100\n* Various fixes for handling dates in headers\n* Update parsing Received header to handle invalid/missing date part https://github.com/DockYard/elixir-mail/pull/96\n* Add allowance for optional seconds and handle invalid hour in time https://github.com/DockYard/elixir-mail/pull/95\n* Fix loop in Mail.Renderers.RFC2822.render_header/2 https://github.com/DockYard/elixir-mail/pull/93\n* Fix invalid base64 encoding which broke in earlier version of Erlang https://github.com/DockYard/elixir-mail/pull/91\n* Add support the Encoded Word RFC 2047 https://github.com/DockYard/elixir-mail/pull/90\n* Retail all \"received\" headers https://github.com/DockYard/elixir-mail/pull/89","ref":"changelog.html#0-2-2-2020-07-28"},{"type":"extras","title":"0.2.1 2019-03-02 - Changelog","doc":"* Fix quoted-printable encoding https://github.com/DockYard/elixir-mail/pull/83\n* Optimized quoted-printable encoder to reduce memory usage https://github.com/DockYard/elixir-mail/pull/87\n* Update RFC2822 email regex with a better one https://github.com/DockYard/elixir-mail/pull/86","ref":"changelog.html#0-2-1-2019-03-02"},{"type":"extras","title":"0.2.0 2017-07-21 - Changelog","doc":"* Breaking - All message props are now binaries https://github.com/DockYard/elixir-mail/pull/69\n* removed `Mail.Message.has_attachment?` and `Mail.Message.has_text_part?` https://github.com/DockYard/elixir-mail/pull/74\n* added `Mail.has_attachments?` and `Mail.has_text_parts?` https://github.com/DockYard/elixir-mail/pull/74\n* added `Mail.get_attachments` https://github.com/DockYard/elixir-mail/pull/75\n* Allow RFC2822 email regex to be overridden by config https://github.com/DockYard/elixir-mail/pull/73\n* Allow `Mail.put_attachment` to use in-memory data in tuple https://github.com/DockYard/elixir-mail/pull/58\n* Support obsolete timestamps https://github.com/DockYard/elixir-mail/pull/70\n* Fix test suite for Elixir 1.4+ https://github.com/DockYard/elixir-mail/pull/67","ref":"changelog.html#0-2-0-2017-07-21"},{"type":"extras","title":"0.1.1 2016-10-12 - Changelog","doc":"* Moved API to using strings instead of atoms\n* Parser and Renderer should handle reply-to header","ref":"changelog.html#0-1-1-2016-10-12"},{"type":"extras","title":"0.1.0 2016-07-31 - Changelog","doc":"* API is stable enough for a minor version release\n* Resolved Elixir 1.3 warnings","ref":"changelog.html#0-1-0-2016-07-31"},{"type":"extras","title":"0.0.3 2016-03-14 - Changelog","doc":"* Began multipart support. The `Mail` struct can have multiple \"parts\".\n  Each `Mail.Part` can have multiple \"parts\".\n* Added RFC2822 Renderer\n* Added RFC2822 Parser","ref":"changelog.html#0-0-3-2016-03-14"},{"type":"extras","title":"Mail","doc":"# Mail\n\n![Build Status](https://github.com/DockYard/elixir-mail/actions/workflows/main.yml/badge.svg)\n\nAn RFC2822 implementation in Elixir, built for composability.\n\n**[Mail is built and maintained by DockYard, contact us for expert Elixir and Phoenix consulting](https://dockyard.com/phoenix-consulting)**.","ref":"readme.html"},{"type":"extras","title":"Installation - Mail","doc":"```elixir\ndef deps do\n  [\n    # Get from hex\n    {:mail, \"~> 0.4\"},\n\n    # Or use the latest from master\n    {:mail, github: \"DockYard/elixir-mail\"}\n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"Building - Mail","doc":"You can quickly build an RFC2822 spec compliant message.\n\n##","ref":"readme.html#building"},{"type":"extras","title":"Single-Part - Mail","doc":"```elixir\nmessage =\n  Mail.build()\n  |> Mail.put_text(\"A great message\")\n  |> Mail.put_to(\"bob@example.com\")\n  |> Mail.put_from(\"me@example.com\")\n  |> Mail.put_subject(\"Open me\")\n```\n\n##","ref":"readme.html#single-part"},{"type":"extras","title":"Multi-Part - Mail","doc":"```elixir\nmessage =\n  Mail.build_multipart()\n  |> Mail.put_text(\"Hello there!\")\n  |> Mail.put_html(\" Hello there! \")\n  |> Mail.put_attachment(\"path/to/README.md\")\n  |> Mail.put_attachment({\"README.md\", file_data})\n```","ref":"readme.html#multi-part"},{"type":"extras","title":"Rendering - Mail","doc":"After you have built your message you can render it:\n\n```elixir\nrendered_message = Mail.render(message)\n```","ref":"readme.html#rendering"},{"type":"extras","title":"Parsing - Mail","doc":"If you'd like to parse an already rendered message back into\na data model:\n\n```elixir\n%Mail.Message{} = message = Mail.parse(rendered_message)\n```\n\n[There are more functions described in the docs](https://hexdocs.pm/mail/Mail.html)","ref":"readme.html#parsing"},{"type":"extras","title":"Authors ## - Mail","doc":"* [Brian Cardarella](https://twitter.com/bcardarella)\n\n[We are very thankful for the many contributors](https://github.com/dockyard/elixir-mail/graphs/contributors)","ref":"readme.html#authors"},{"type":"extras","title":"Versioning ## - Mail","doc":"This library follows [Semantic Versioning](https://semver.org)","ref":"readme.html#versioning"},{"type":"extras","title":"Looking for help with your Elixir project? ## - Mail","doc":"[At DockYard we are ready to help you build your next Elixir project](https://dockyard.com/phoenix-consulting). We have a unique expertise\nin Elixir and Phoenix development that is unmatched. [Get in touch!](https://dockyard.com/contact/hire-us)\n\nAt DockYard we love Elixir! You can [read our Elixir blog posts](https://dockyard.com/blog/categories/elixir)\nor come visit us at [The Boston Elixir Meetup](https://www.meetup.com/Boston-Elixir/) that we organize.","ref":"readme.html#looking-for-help-with-your-elixir-project"},{"type":"extras","title":"Want to help? ## - Mail","doc":"Please do! We are always looking to improve this library. Please see our\n[Contribution Guidelines](https://github.com/dockyard/elixir-mail/blob/master/CONTRIBUTING.md)\non how to properly submit issues and pull requests.","ref":"readme.html#want-to-help"},{"type":"extras","title":"Legal ## - Mail","doc":"[DockYard](https://dockyard.com/), Inc. © 2015\n\n[@dockyard](https://twitter.com/dockyard)\n\n[Licensed under the MIT license](https://www.opensource.org/licenses/mit-license.php)","ref":"readme.html#legal"}],"content_type":"text/markdown"}